==> dlh_0.1.1-1.tar.gz: dlh-0.1.1/src/dlh_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>About</name>
    <message>
        <location filename="about.ui" line="14"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="about.ui" line="32"/>
        <source>Daddy&apos;s Little Helper</source>
        <translation>Daddy&apos;s Little Helper</translation>
    </message>
    <message>
        <location filename="about.ui" line="42"/>
        <source>Infant feeding log application</source>
        <translation>Diario poppate per genitori tecnologici</translation>
    </message>
    <message>
        <location filename="about.ui" line="52"/>
        <source>&lt;a href=&quot;mailto:marcello.m@yahoo.com&quot;&gt;Contact the author&lt;/a&gt;</source>
        <oldsource>&lt;a href=&quot;mailto:marcello.m@yahoo.com&quot;&gt; Contact the author&lt;/a&gt;</oldsource>
        <translation>&lt;a href=&quot;mailto:marcello.m@yahoo.com&quot;&gt;Contatta l&apos;autore&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="about.ui" line="68"/>
        <source>&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=2FNZDD4WUBS9J&amp;lc=US&amp;item_name=FOSS%20development&amp;item_number=FOSS&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donateCC_LG%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt; </source>
        <translation>&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=2FNZDD4WUBS9J&amp;lc=US&amp;item_name=FOSS%20development&amp;item_number=FOSS&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donateCC_LG%2egif%3aNonHosted&quot;&gt;DONA&lt;/a&gt; </translation>
    </message>
    <message>
        <source>marcello.m@yahoo.com</source>
        <translation type="obsolete">marcello.m@yahoo.com</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="dlh.cpp" line="32"/>
        <source>Cannot open database</source>
        <translation>Impossibile aprire il database</translation>
    </message>
    <message>
        <location filename="dlh.cpp" line="33"/>
        <source>Unable to establish a database connection.

Click Cancel to exit.</source>
        <translation>Impossibile stabilire una connessione con il database.

Premi Annulla per uscire.</translation>
    </message>
    <message>
        <location filename="view.cpp" line="36"/>
        <source>Start time</source>
        <translation>Inizio</translation>
    </message>
    <message>
        <location filename="view.cpp" line="37"/>
        <source>Finish time</source>
        <translation>Fine</translation>
    </message>
    <message>
        <location filename="view.cpp" line="38"/>
        <source>Weight before</source>
        <translation>Peso prima</translation>
    </message>
    <message>
        <location filename="view.cpp" line="39"/>
        <source>Weight after</source>
        <translation>Peso dopo</translation>
    </message>
    <message>
        <location filename="view.cpp" line="40"/>
        <source>Weight difference</source>
        <translation>Differenza di peso</translation>
    </message>
    <message>
        <location filename="view.cpp" line="41"/>
        <source>ml before</source>
        <translation>ml prima</translation>
    </message>
    <message>
        <location filename="view.cpp" line="42"/>
        <source>ml after</source>
        <translation>ml dopo</translation>
    </message>
    <message>
        <location filename="view.cpp" line="43"/>
        <source>ml difference</source>
        <translation>differenza di ml</translation>
    </message>
</context>
<context>
    <name>Start</name>
    <message>
        <location filename="start.ui" line="14"/>
        <source>Insert data</source>
        <translation>Inserimento dati</translation>
    </message>
    <message>
        <location filename="start.ui" line="24"/>
        <source>Start time:</source>
        <translation>Inizio:</translation>
    </message>
    <message>
        <location filename="start.ui" line="31"/>
        <source>End time:</source>
        <translation>Fine:</translation>
    </message>
    <message>
        <location filename="start.ui" line="91"/>
        <source>Edit times    </source>
        <translation>Modifica tempi    </translation>
    </message>
    <message>
        <location filename="start.ui" line="98"/>
        <source>Finish</source>
        <translation>Fine</translation>
    </message>
    <message>
        <location filename="start.ui" line="126"/>
        <source>Weight before:</source>
        <translation>Peso prima:</translation>
    </message>
    <message>
        <location filename="start.ui" line="133"/>
        <source>Weight after:</source>
        <translation>Peso dopo:</translation>
    </message>
    <message>
        <location filename="start.ui" line="150"/>
        <location filename="start.ui" line="163"/>
        <location filename="start.ui" line="198"/>
        <location filename="start.ui" line="211"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="start.ui" line="174"/>
        <source>ml before:</source>
        <translation>ml prima:</translation>
    </message>
    <message>
        <location filename="start.ui" line="181"/>
        <source>ml after:</source>
        <translation>ml dopo:</translation>
    </message>
</context>
<context>
    <name>View</name>
    <message>
        <location filename="view.ui" line="14"/>
        <source>View data</source>
        <translation>Visualizzazione dati</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="dlh.ui" line="14"/>
        <source>Daddy&apos;s Little Helper</source>
        <translation>Daddy&apos;s Little Helper</translation>
    </message>
    <message>
        <location filename="dlh.ui" line="22"/>
        <source>Start</source>
        <translation>Inizio</translation>
    </message>
    <message>
        <location filename="dlh.ui" line="29"/>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <location filename="dlh.ui" line="40"/>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <location filename="dlh.ui" line="47"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="dlh.cpp" line="110"/>
        <source>Are you sure?</source>
        <translation>Sei sicuro?</translation>
    </message>
    <message>
        <location filename="dlh.cpp" line="111"/>
        <source>This operation is undoable!!!</source>
        <translation>Questa operazione non si può annullare!!!</translation>
    </message>
</context>
</TS>

==> dlh_0.1-2.tar.gz: dlh-0.1/src/dlh_it_IT.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>About</name>
    <message>
        <location filename="about.ui" line="14"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="about.ui" line="32"/>
        <source>Daddy&apos;s Little Helper</source>
        <translation>Daddy&apos;s Little Helper</translation>
    </message>
    <message>
        <location filename="about.ui" line="39"/>
        <source>Infant feeding log application</source>
        <translation>Diario poppate per genitori tecnologici</translation>
    </message>
    <message>
        <location filename="about.ui" line="46"/>
        <source>marcello.m@yahoo.com</source>
        <translation>marcello.m@yahoo.com</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="dlh.cpp" line="32"/>
        <source>Cannot open database</source>
        <translation>Impossibile aprire il database</translation>
    </message>
    <message>
        <location filename="dlh.cpp" line="33"/>
        <source>Unable to establish a database connection.

Click Cancel to exit.</source>
        <translation>Impossibile stabilire una connessione con il database.

Premi Annulla per uscire.</translation>
    </message>
    <message>
        <location filename="view.cpp" line="36"/>
        <source>Start time</source>
        <translation>Inizio</translation>
    </message>
    <message>
        <location filename="view.cpp" line="37"/>
        <source>Finish time</source>
        <translation>Fine</translation>
    </message>
    <message>
        <location filename="view.cpp" line="38"/>
        <source>Weight before</source>
        <translation>Peso prima</translation>
    </message>
    <message>
        <location filename="view.cpp" line="39"/>
        <source>Weight after</source>
        <translation>Peso dopo</translation>
    </message>
    <message>
        <location filename="view.cpp" line="40"/>
        <source>Weight difference</source>
        <translation>Differenza di peso</translation>
    </message>
    <message>
        <location filename="view.cpp" line="41"/>
        <source>ml before</source>
        <translation>ml prima</translation>
    </message>
    <message>
        <location filename="view.cpp" line="42"/>
        <source>ml after</source>
        <translation>ml dopo</translation>
    </message>
    <message>
        <location filename="view.cpp" line="43"/>
        <source>ml difference</source>
        <translation>differenza di ml</translation>
    </message>
</context>
<context>
    <name>Start</name>
    <message>
        <location filename="start.ui" line="14"/>
        <source>Insert data</source>
        <translation>Inserimento dati</translation>
    </message>
    <message>
        <location filename="start.ui" line="24"/>
        <source>Start time:</source>
        <translation>Inizio:</translation>
    </message>
    <message>
        <location filename="start.ui" line="31"/>
        <source>End time:</source>
        <translation>Fine:</translation>
    </message>
    <message>
        <location filename="start.ui" line="91"/>
        <source>Edit times    </source>
        <translation>Modifica tempi    </translation>
    </message>
    <message>
        <location filename="start.ui" line="98"/>
        <source>Finish</source>
        <translation>Fine</translation>
    </message>
    <message>
        <location filename="start.ui" line="126"/>
        <source>Weight before:</source>
        <translation>Peso prima:</translation>
    </message>
    <message>
        <location filename="start.ui" line="133"/>
        <source>Weight after:</source>
        <translation>Peso dopo:</translation>
    </message>
    <message>
        <location filename="start.ui" line="150"/>
        <location filename="start.ui" line="163"/>
        <location filename="start.ui" line="198"/>
        <location filename="start.ui" line="211"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="start.ui" line="174"/>
        <source>ml before:</source>
        <translation>ml prima:</translation>
    </message>
    <message>
        <location filename="start.ui" line="181"/>
        <source>ml after:</source>
        <translation>ml dopo:</translation>
    </message>
</context>
<context>
    <name>View</name>
    <message>
        <location filename="view.ui" line="14"/>
        <source>View data</source>
        <translation>Visualizzazione dati</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <location filename="dlh.ui" line="14"/>
        <source>Daddy&apos;s Little Helper</source>
        <translation>Daddy&apos;s Little Helper</translation>
    </message>
    <message>
        <location filename="dlh.ui" line="22"/>
        <source>Start</source>
        <translation>Inizio</translation>
    </message>
    <message>
        <location filename="dlh.ui" line="29"/>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <location filename="dlh.ui" line="40"/>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <location filename="dlh.ui" line="47"/>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="dlh.cpp" line="110"/>
        <source>Are you sure?</source>
        <translation>Sei sicuro?</translation>
    </message>
    <message>
        <location filename="dlh.cpp" line="111"/>
        <source>This operation is undoable!!!</source>
        <translation>Questa operazione non si può annullare!!!</translation>
    </message>
</context>
</TS>
